/*                                                       
 *   _____ _____ _____ _____ _____ _____ _____ _____ __    
 *  |_   _|   __|_   _| __  |  _  |  |  |  _  |  _  |  |   
 *    | | |   __| | | |    -|     |  |  |     |     |  |__ 
 *    |_| |_____| |_| |__|__|__|__|\___/|__|__|__|__|_____|   
 *    
 *  -------------------------------------------------------
 *  
 *  AUTHORIZED SERVICE PERSONNEL ONLY
 *  Tetravaal certification BPED3 or greater authorized
 *  for code changes. Please consult official manual for
 *  additional instructions and help options.
 *  
 *  TETRA.V Mainframe Series 7 - R34 H773-ONBOARD  
 *  Reference current version service manual [TVWS-D-R34]
 *  
 *  ------------------------------------------------------
 *  
 *  BKAMP(R) . CPEARCE(R) . PBACK(R) . DIOS(R)
 *  
 */

#include <Adafruit_ImageReader_EPD.h>
#include <Adafruit_ImageReader.h>
#include <Adafruit_GFX.h>  
#include <Adafruit_ST7789.h>
#include <Adafruit_ImageReader.h>
#include <SdFat.h>                


#include <SPI.h>
#include <Fonts/bt.h>
#include <Fonts/gc.h>

#define SD_CS         4 
#define TFT_CS        10
#define TFT_RST        9
#define TFT_DC         8

#define BLACK    0x00003
#define BLUE     0x011F 
#define WHITE    0xFFFF
#define GREY     0xCE79

#define USE_SD_CARD

Adafruit_ST7789 tft = Adafruit_ST7789(TFT_CS, TFT_DC, TFT_RST);
SdFat                SD;         
Adafruit_ImageReader reader(SD); 

const int REED_CPU = 2;
const int REED_MIP = 3;

void setup() {

  Serial.begin(9600);
  
  tft.init(240,320);
  tft.setRotation(1);
  
  if(!SD.begin(SD_CS, SD_SCK_MHZ(25))) { // ESP32 requires 25 MHz limit
  Serial.println(F("SD begin() failed"));
  for(;;); // Fatal error, do not continue
  }

  pinMode(REED_CPU, INPUT_PULLUP);
  pinMode(REED_MIP, INPUT_PULLUP);

  ImageReturnCode stat;
  stat = reader.drawBMP("/dk01.bmp", tft, 0, 0);
  delay(1000);
  stat = reader.drawBMP("/dk02.bmp", tft, 0, 0);
  stat = reader.drawBMP("/dk03.bmp", tft, 0, 0);
  stat = reader.drawBMP("/dk04.bmp", tft, 0, 0);
  delay(1000);
  
}

void loop() 
{
  int proximityCPU = digitalRead(REED_CPU);
  int proximityMIP = digitalRead(REED_MIP);

  ImageReturnCode stat;
  
  if (proximityCPU == LOW && proximityMIP == LOW) { // DIAGNOSTIC_BOOT_SEQUENCE - CPU: OK | MIP: OK - STATUS: *GOOD*
    stat = reader.drawBMP("/dgood.bmp", tft, 0, 0);
    }

  if (proximityCPU == LOW && proximityMIP == HIGH) { // DIAGNOSTIC_BOOT_SEQUENCE - CPU: OK | MIP: NO - STATUS: *WARNING*
    stat = reader.drawBMP("/dwarn.bmp", tft, 0,0);    
  }

  if (proximityCPU == HIGH && proximityMIP == LOW) { // DIAGNOSTIC_BOOT_SEQUENCE - CPU: NO | MIP: OK - STATUS: *NOCPU*
    stat = reader.drawBMP("/dbreach.bmp", tft, 0, 0);
    delay(1000);
    stat = reader.drawBMP("/dnocpu.bmp", tft, 0, 0);    
  }

  if (proximityCPU == HIGH && proximityMIP == HIGH) { // DIAGNOSTIC_BOOT_SEQUENCE - CPU: NO | MIP: NO - STATUS: *FAILSAFE*
    stat = reader.drawBMP("/dshut.bmp", tft, 0, 0);    
  }


}
